==> beast-privilege-api-2.6.4-GS-20230109.025124-14-sources.jar: com/thebeastshop/privilege/vo/GiftCampaignRuleSkuVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class GiftCampaignRuleSkuVO implements Serializable {
    private Integer id;
    private Integer campaignId; //赠品活动ID
    private Integer groupNum; //几号赠品池
    private BigDecimal price; //满多少元赠送
    private Boolean isDouble; //是否倍送 1是0否
    private String skuCode; //sku编码

    private String  skuName;

    private Integer quantity; //赠送数量
    private Integer limitQuantity; //赠送总量限制
    private Integer sort; //赠送顺序
    private Integer isCustomerVisible; //用户可见 1是0否

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getCampaignId() {
        return campaignId;
    }

    public void setCampaignId(Integer campaignId) {
        this.campaignId = campaignId;
    }

    public Integer getGroupNum() {
        return groupNum;
    }

    public void setGroupNum(Integer groupNum) {
        this.groupNum = groupNum;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Boolean getDouble() {
        return isDouble;
    }

    public void setDouble(Boolean aDouble) {
        isDouble = aDouble;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Integer getLimitQuantity() {
        return limitQuantity;
    }

    public void setLimitQuantity(Integer limitQuantity) {
        this.limitQuantity = limitQuantity;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Integer getIsCustomerVisible() {
        return isCustomerVisible;
    }

    public void setIsCustomerVisible(Integer isCustomerVisible) {
        this.isCustomerVisible = isCustomerVisible;
    }


}

==> beast-privilege-api-3.0.11-GS-20250828.064804-2-sources.jar: com/thebeastshop/privilege/vo/GiftCampaignRuleSkuVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class GiftCampaignRuleSkuVO implements Serializable {
    private Integer id;
    private Integer campaignId; //赠品活动ID
    private Integer groupNum; //几号赠品池
    private BigDecimal price; //满多少元赠送
    private Boolean isDouble; //是否倍送 1是0否
    private String skuCode; //sku编码

    private String  skuName;

    private Integer quantity; //赠送数量
    private Integer limitQuantity; //赠送总量限制
    private Integer sort; //赠送顺序
    private Integer isCustomerVisible; //用户可见 1是0否



    private Integer canUseQuantity; //可用库存

    private Integer giftedAmount;   //已赠送数量


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getCampaignId() {
        return campaignId;
    }

    public void setCampaignId(Integer campaignId) {
        this.campaignId = campaignId;
    }

    public Integer getGroupNum() {
        return groupNum;
    }

    public void setGroupNum(Integer groupNum) {
        this.groupNum = groupNum;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Boolean getIsDouble() {
        return isDouble;
    }

    public void setIsDouble(Boolean aDouble) {
        isDouble = aDouble;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Integer getLimitQuantity() {
        return limitQuantity;
    }

    public void setLimitQuantity(Integer limitQuantity) {
        this.limitQuantity = limitQuantity;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Integer getIsCustomerVisible() {
        return isCustomerVisible;
    }

    public void setIsCustomerVisible(Integer isCustomerVisible) {
        this.isCustomerVisible = isCustomerVisible;
    }
    public Integer getCanUseQuantity() {
        return canUseQuantity;
    }

    public void setCanUseQuantity(Integer canUseQuantity) {
        this.canUseQuantity = canUseQuantity;
    }

    public Integer getGiftedAmount() {
        return giftedAmount;
    }

    public void setGiftedAmount(Integer giftedAmount) {
        this.giftedAmount = giftedAmount;
    }

}
